@@ -5,7 +5,6 @@
 #include "src/definitions.h"
 #include "src/ttrssfeed.h"
 
-#include <librssguard/3rd-party/boolinq/boolinq.h>
 #include <librssguard/definitions/definitions.h>
 #include <librssguard/exceptions/feedfetchexception.h>
 #include <librssguard/miscellaneous/application.h>
@@ -18,6 +17,7 @@
 #include <librssguard/services/abstract/labelsnode.h>
 #include <librssguard/services/abstract/rootitem.h>
 #include <librssguard/services/abstract/serviceroot.h>
+#include <qtlinq/qtlinq.h>
 
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -924,7 +924,7 @@ RootItem* TtRssGetFeedsCategoriesResponse::feedsCategories(TtRssNetworkFactory*
     QVector<QPair<RootItem*, QJsonValue>> pairs;
     pairs.reserve(items_to_process.size());
 
-    for (const QJsonValue& item : items_to_process) {
+    for (const QJsonValue& item : std::as_const(items_to_process)) {
       pairs.append(QPair<RootItem*, QJsonValue>(parent, item));
     }
 
@@ -1033,8 +1033,9 @@ TtRssGetArticleResponse::~TtRssGetArticleResponse() = default;
 QList<Message> TtRssGetHeadlinesResponse::messages(ServiceRoot* root) const {
   QList<Message> messages;
   auto active_labels = root->labelsNode() != nullptr ? root->labelsNode()->labels() : QList<Label*>();
+  auto labels_linq = qlinq::from(active_labels);
   auto json_msgs = m_rawContent[QSL("content")].toArray();
-  auto* published_lbl = boolinq::from(active_labels).firstOrDefault([](const Label* lbl) {
+  auto published_lbl = labels_linq.firstOrDefault([](const Label* lbl) {
     return lbl->customNumericId() == TTRSS_PUBLISHED_LABEL_ID;
   });
 
@@ -1048,22 +1049,21 @@ QList<Message> TtRssGetHeadlinesResponse::messages(ServiceRoot* root) const {
     message.m_contents = mapped[QSL("content")].toString();
     message.m_rawContents = QJsonDocument(mapped).toJson(QJsonDocument::JsonFormat::Compact);
 
-    if (published_lbl != nullptr && mapped[QSL("published")].toBool()) {
+    if (published_lbl.has_value() && mapped[QSL("published")].toBool()) {
       // Article is published, set label.
-      message.m_assignedLabels.append(published_lbl);
+      message.m_assignedLabels.append(published_lbl.value());
     }
 
     auto json_labels = mapped[QSL("labels")].toArray();
 
     for (const QJsonValue& lbl_val : std::as_const(json_labels)) {
       QString lbl_custom_id = QString::number(lbl_val.toArray().at(0).toInt());
-      Label* label =
-        boolinq::from(active_labels.begin(), active_labels.end()).firstOrDefault([lbl_custom_id](Label* lbl) {
-          return lbl->customId() == lbl_custom_id;
-        });
+      auto label = labels_linq.firstOrDefault([lbl_custom_id](Label* lbl) {
+        return lbl->customId() == lbl_custom_id;
+      });
 
-      if (label != nullptr) {
-        message.m_assignedLabels.append(label);
+      if (label.has_value()) {
+        message.m_assignedLabels.append(label.value());
       }
       else {
         qWarningNN << LOGSEC_TTRSS << "Label with custom ID" << QUOTE_W_SPACE(lbl_custom_id)
@@ -1078,9 +1078,6 @@ QList<Message> TtRssGetHeadlinesResponse::messages(ServiceRoot* root) const {
     message.m_created = TextFactory::parseDateTime(t);
     message.m_createdFromFeed = true;
     message.m_customId = QString::number(mapped[QSL("id")].toInt());
-    message.m_feedId = mapped[QSL("feed_id")].type() == QJsonValue::Type::Double
-                         ? QString::number(mapped[QSL("feed_id")].toInt())
-                         : mapped[QSL("feed_id")].toString();
     message.m_title = mapped[QSL("title")].toString();
     message.m_url = mapped[QSL("link")].toString();
 
@@ -1090,11 +1087,10 @@ QList<Message> TtRssGetHeadlinesResponse::messages(ServiceRoot* root) const {
 
       for (const QJsonValue& attachment : std::as_const(json_att)) {
         QJsonObject mapped_attachemnt = attachment.toObject();
-        Enclosure enclosure;
+        MessageEnclosure* enclosure = new MessageEnclosure(mapped_attachemnt[QSL("content_type")].toString(),
+                                                           mapped_attachemnt[QSL("content_url")].toString());
 
-        enclosure.m_mimeType = mapped_attachemnt[QSL("content_type")].toString();
-        enclosure.m_url = mapped_attachemnt[QSL("content_url")].toString();
-        message.m_enclosures.append(enclosure);
+        message.m_enclosures.append(QSharedPointer<MessageEnclosure>(enclosure));
       }
     }
 
@@ -1172,7 +1168,8 @@ QList<RootItem*> TtRssGetLabelsResponse::labels() const {
   //
   // This label solves situation 1). 2) is solved in other way (creating static system feed).
   QString published_caption = QSL("[SYSTEM] ") + QObject::tr("Published articles");
-  auto* published_lbl = new Label(published_caption, TextFactory::generateColorFromText(published_caption));
+  auto* published_lbl =
+    new Label(published_caption, IconFactory::fromColor(TextFactory::generateColorFromText(published_caption)));
 
   published_lbl->setKeepOnTop(true);
   published_lbl->setCustomId(QString::number(TTRSS_PUBLISHED_LABEL_ID));
@@ -1180,7 +1177,8 @@ QList<RootItem*> TtRssGetLabelsResponse::labels() const {
 
   for (const QJsonValue& lbl_val : std::as_const(json_labels)) {
     QJsonObject lbl_obj = lbl_val.toObject();
-    Label* lbl = new Label(lbl_obj[QSL("caption")].toString(), QColor(lbl_obj[QSL("fg_color")].toString()));
+    Label* lbl = new Label(lbl_obj[QSL("caption")].toString(),
+                           IconFactory::fromColor(QColor(lbl_obj[QSL("fg_color")].toString())));
 
     lbl->setCustomId(QString::number(lbl_obj[QSL("id")].toInt()));
     labels.append(lbl);
